@@ -1,4 +1,4 @@
-metaComputeModules <- function(moduleObject, N=5, method="DormannStrauss", ...){
+metaComputeModules <- function(moduleObject, N=5, method="Beckett", ...){
     attempts <- list()
     for (i in 1:N){
         attempts[[i]] <- computeModules(moduleObject, method=method, ...)
